@@ -1,10 +1,6 @@
-# Copyright (c) 2016, 2018 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016 Ceridwen <ceridwenv@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
-
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 from astroid import parse
 from astroid.brain.helpers import register_module_extender
@@ -71,4 +67,5 @@ _namespace_packages = {}
     )
 
 
-register_module_extender(AstroidManager(), "pkg_resources", pkg_resources_transform)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "pkg_resources", pkg_resources_transform)
